#!/usr/bin/env python
# encoding: utf-8

"""This extension provides support for clusters using Kerberos authentication.

Namely, it adds a new :class:`~hdfs.client.Client` subclass,
:class:`KerberosClient`, which handles authentication appropriately.

"""

from ..client import Client
from requests_kerberos import HTTPKerberosAuth, OPTIONAL


class KerberosClient(Client):

  """HDFS web client using Kerberos authentication.

  :param url: Hostname or IP address of HDFS namenode, prefixed with protocol,
    followed by WebHDFS port on namenode
  :param proxy: User to proxy as.
  :param root: Root path. Used to allow relative path parameters.

  """

  def __init__(self, url, proxy=None, root=None):
    super(KerberosClient, self).__init__(
      url,
      auth=HTTPKerberosAuth(OPTIONAL),
      proxy=proxy,
      root=root,
    )



#!/usr/bin/env python

"""HdfsCLI: a command line interface for WebHDFS."""

from hdfs import __version__
from setuptools import find_packages, setup


setup(
    name='hdfs',
    version=__version__,
    description=__doc__,
    long_description=open('README.rst').read(),
    author='Matthieu Monsch',
    author_email='monsch@alum.mit.edu',
    url='http://hdfscli.readthedocs.org',
    license='MIT',
    packages=find_packages(),
    classifiers=[
      'Development Status :: 3 - Alpha',
      'Intended Audience :: Developers',
      'License :: OSI Approved :: MIT License',
      'Programming Language :: Python',
      'Programming Language :: Python :: 2.6',
      'Programming Language :: Python :: 2.7',
    ],
    install_requires=[
      'docopt',
      'requests>=2.0.1',
    ],
    extras_require={
      'avro': ['avro'],
      'kerberos': ['requests-kerberos'],
      'dataframe': ['numpy', 'pandas>=0.14.1', 'fastavro'],
    },
    entry_points={'console_scripts': [
      'hdfs = hdfs.__main__:main',
      'hdfsavro = hdfs.ext.avro:main',
    ]},
)
